# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import plugin_pb2 as plugin__pb2


class NodeStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Init = channel.unary_unary(
        '/proto.Node/Init',
        request_serializer=plugin__pb2.InitRequest.SerializeToString,
        response_deserializer=plugin__pb2.Empty.FromString,
        )
    self.OnCreate = channel.unary_unary(
        '/proto.Node/OnCreate',
        request_serializer=plugin__pb2.OnCreateRequest.SerializeToString,
        response_deserializer=plugin__pb2.OnCreateResponse.FromString,
        )
    self.OnMessage = channel.unary_unary(
        '/proto.Node/OnMessage',
        request_serializer=plugin__pb2.OnMessageRequest.SerializeToString,
        response_deserializer=plugin__pb2.OnMessageResponse.FromString,
        )
    self.OnClose = channel.unary_unary(
        '/proto.Node/OnClose',
        request_serializer=plugin__pb2.OnCloseRequest.SerializeToString,
        response_deserializer=plugin__pb2.OnCloseResponse.FromString,
        )


class NodeServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Init(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OnCreate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OnMessage(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OnClose(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_NodeServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Init': grpc.unary_unary_rpc_method_handler(
          servicer.Init,
          request_deserializer=plugin__pb2.InitRequest.FromString,
          response_serializer=plugin__pb2.Empty.SerializeToString,
      ),
      'OnCreate': grpc.unary_unary_rpc_method_handler(
          servicer.OnCreate,
          request_deserializer=plugin__pb2.OnCreateRequest.FromString,
          response_serializer=plugin__pb2.OnCreateResponse.SerializeToString,
      ),
      'OnMessage': grpc.unary_unary_rpc_method_handler(
          servicer.OnMessage,
          request_deserializer=plugin__pb2.OnMessageRequest.FromString,
          response_serializer=plugin__pb2.OnMessageResponse.SerializeToString,
      ),
      'OnClose': grpc.unary_unary_rpc_method_handler(
          servicer.OnClose,
          request_deserializer=plugin__pb2.OnCloseRequest.FromString,
          response_serializer=plugin__pb2.OnCloseResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'proto.Node', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))


class RuntimeHelperStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Close = channel.unary_unary(
        '/proto.RuntimeHelper/Close',
        request_serializer=plugin__pb2.Empty.SerializeToString,
        response_deserializer=plugin__pb2.Empty.FromString,
        )
    self.Debug = channel.unary_unary(
        '/proto.RuntimeHelper/Debug',
        request_serializer=plugin__pb2.DebugRequest.SerializeToString,
        response_deserializer=plugin__pb2.Empty.FromString,
        )
    self.EmitFlowEvent = channel.unary_unary(
        '/proto.RuntimeHelper/EmitFlowEvent',
        request_serializer=plugin__pb2.EmitFlowEventRequest.SerializeToString,
        response_deserializer=plugin__pb2.Empty.FromString,
        )
    self.EmitOutput = channel.unary_unary(
        '/proto.RuntimeHelper/EmitOutput',
        request_serializer=plugin__pb2.EmitOutputRequest.SerializeToString,
        response_deserializer=plugin__pb2.Empty.FromString,
        )
    self.EmitError = channel.unary_unary(
        '/proto.RuntimeHelper/EmitError',
        request_serializer=plugin__pb2.EmitErrorRequest.SerializeToString,
        response_deserializer=plugin__pb2.Empty.FromString,
        )
    self.GetVaultItem = channel.unary_unary(
        '/proto.RuntimeHelper/GetVaultItem',
        request_serializer=plugin__pb2.GetVaultItemRequest.SerializeToString,
        response_deserializer=plugin__pb2.GetVaultItemResponse.FromString,
        )
    self.GetIntVariable = channel.unary_unary(
        '/proto.RuntimeHelper/GetIntVariable',
        request_serializer=plugin__pb2.GetVariableRequest.SerializeToString,
        response_deserializer=plugin__pb2.GetIntVariableResponse.FromString,
        )
    self.GetStringVariable = channel.unary_unary(
        '/proto.RuntimeHelper/GetStringVariable',
        request_serializer=plugin__pb2.GetVariableRequest.SerializeToString,
        response_deserializer=plugin__pb2.GetStringVariableResponse.FromString,
        )
    self.GetInterfaceVariable = channel.unary_unary(
        '/proto.RuntimeHelper/GetInterfaceVariable',
        request_serializer=plugin__pb2.GetVariableRequest.SerializeToString,
        response_deserializer=plugin__pb2.GetInterfaceVariableResponse.FromString,
        )
    self.SetIntVariable = channel.unary_unary(
        '/proto.RuntimeHelper/SetIntVariable',
        request_serializer=plugin__pb2.SetIntVariableRequest.SerializeToString,
        response_deserializer=plugin__pb2.SetVariableResponse.FromString,
        )
    self.SetStringVariable = channel.unary_unary(
        '/proto.RuntimeHelper/SetStringVariable',
        request_serializer=plugin__pb2.SetStringVariableRequest.SerializeToString,
        response_deserializer=plugin__pb2.SetVariableResponse.FromString,
        )
    self.SetInterfaceVariable = channel.unary_unary(
        '/proto.RuntimeHelper/SetInterfaceVariable',
        request_serializer=plugin__pb2.SetInterfaceVariableRequest.SerializeToString,
        response_deserializer=plugin__pb2.SetVariableResponse.FromString,
        )


class RuntimeHelperServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Close(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Debug(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EmitFlowEvent(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EmitOutput(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EmitError(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetVaultItem(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetIntVariable(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetStringVariable(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetInterfaceVariable(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetIntVariable(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetStringVariable(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetInterfaceVariable(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RuntimeHelperServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Close': grpc.unary_unary_rpc_method_handler(
          servicer.Close,
          request_deserializer=plugin__pb2.Empty.FromString,
          response_serializer=plugin__pb2.Empty.SerializeToString,
      ),
      'Debug': grpc.unary_unary_rpc_method_handler(
          servicer.Debug,
          request_deserializer=plugin__pb2.DebugRequest.FromString,
          response_serializer=plugin__pb2.Empty.SerializeToString,
      ),
      'EmitFlowEvent': grpc.unary_unary_rpc_method_handler(
          servicer.EmitFlowEvent,
          request_deserializer=plugin__pb2.EmitFlowEventRequest.FromString,
          response_serializer=plugin__pb2.Empty.SerializeToString,
      ),
      'EmitOutput': grpc.unary_unary_rpc_method_handler(
          servicer.EmitOutput,
          request_deserializer=plugin__pb2.EmitOutputRequest.FromString,
          response_serializer=plugin__pb2.Empty.SerializeToString,
      ),
      'EmitError': grpc.unary_unary_rpc_method_handler(
          servicer.EmitError,
          request_deserializer=plugin__pb2.EmitErrorRequest.FromString,
          response_serializer=plugin__pb2.Empty.SerializeToString,
      ),
      'GetVaultItem': grpc.unary_unary_rpc_method_handler(
          servicer.GetVaultItem,
          request_deserializer=plugin__pb2.GetVaultItemRequest.FromString,
          response_serializer=plugin__pb2.GetVaultItemResponse.SerializeToString,
      ),
      'GetIntVariable': grpc.unary_unary_rpc_method_handler(
          servicer.GetIntVariable,
          request_deserializer=plugin__pb2.GetVariableRequest.FromString,
          response_serializer=plugin__pb2.GetIntVariableResponse.SerializeToString,
      ),
      'GetStringVariable': grpc.unary_unary_rpc_method_handler(
          servicer.GetStringVariable,
          request_deserializer=plugin__pb2.GetVariableRequest.FromString,
          response_serializer=plugin__pb2.GetStringVariableResponse.SerializeToString,
      ),
      'GetInterfaceVariable': grpc.unary_unary_rpc_method_handler(
          servicer.GetInterfaceVariable,
          request_deserializer=plugin__pb2.GetVariableRequest.FromString,
          response_serializer=plugin__pb2.GetInterfaceVariableResponse.SerializeToString,
      ),
      'SetIntVariable': grpc.unary_unary_rpc_method_handler(
          servicer.SetIntVariable,
          request_deserializer=plugin__pb2.SetIntVariableRequest.FromString,
          response_serializer=plugin__pb2.SetVariableResponse.SerializeToString,
      ),
      'SetStringVariable': grpc.unary_unary_rpc_method_handler(
          servicer.SetStringVariable,
          request_deserializer=plugin__pb2.SetStringVariableRequest.FromString,
          response_serializer=plugin__pb2.SetVariableResponse.SerializeToString,
      ),
      'SetInterfaceVariable': grpc.unary_unary_rpc_method_handler(
          servicer.SetInterfaceVariable,
          request_deserializer=plugin__pb2.SetInterfaceVariableRequest.FromString,
          response_serializer=plugin__pb2.SetVariableResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'proto.RuntimeHelper', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
